function result = remoteEval(this, cmd)
%REMOTEEVAL evaluate a matlab command on a remotely connected MATLAB
%
%   RESULT = REMOTEEVAL(THIS, CMD) sends a MATLAB command to a remote server
%   instance and waits for the result to be returned.
%
%   INPUTS:
%       THIS    : current simple.Socket object
%       CMD     : MATLAB command as a string
%
%   OUTPUTS:
%       RESULT  : result from remote MATLAB as a string
%
%   See Also: simple.Socket

    % The command string is sent as a series of bytes preceded by a pair of
    % bytes which represents the length of the string  
    cmd = uint8(cmd);

    len = numel(cmd);
    msb = uint8(floor(len/256));
    lsb = uint8(mod(len,256));

    this.getOutputStream.write([msb, lsb, cmd]);
    
    % We will expect the remote session to return a string in the same format
    % as the command  
    while this.getInputStream.available < 2
    end

    msb = this.getInputStream.read;
    lsb = this.getInputStream.read;

    numChar = 256 * msb + lsb;

    result = uint8(zeros(1, numChar));
    for index = 1:numChar
        result(index) = this.getInputStream.read;
    end
    result = char(result);

end